==> bokain_models-0.2.14.tar.gz: lib/src/editable_model/service.dart <==
part of model_base;

class Service extends EditableModel
{
  @override
  Service() : super()
  {
    serviceAddons = new List();
    roomIds = new List();
    userIds = new List();
  }

  @override
  Service.from(Service other) : super.from(other);

  @override
  Service.decode(Map<String, dynamic> d) : super.decode(d)
  {
    name = d["name"];
    category = d["category"];
    description = d["description"];
    durationMinutes = (d["duration_minutes"] is double) ? d["duration_minutes"] : d["duration_minutes"].toDouble();
    price = (d["price"] is double) ? d["price"] : d["price"].toDouble();
    roomIds = (d.containsKey("room_ids")) ? d["room_ids"] : new List();
    userIds = (d.containsKey(["user_ids"])) ? d["user_ids"] : new List();
    serviceAddons = new List();
    if (d.containsKey("service_addons"))
    {
      List<Map<String, dynamic>> addonsTable = d["service_addons"];
      for (Map<String, dynamic> row in addonsTable)
      {
        serviceAddons.add(new ServiceAddon(row["name"], row["price"], row["duration"]));
      }
    }
  }

  @override
  Map<String, dynamic> get encoded
  {
    Map<String, dynamic> d = super.encoded;
    d["service_addons"] = new List<Map<String, dynamic>>();
    for (ServiceAddon addon in serviceAddons)
    {
      d["service_addons"].add(addon.data);
    }

    return d;
  }

  @override
  Map<String, String> get toTable
  {
    Map<String, String> table = new Map();
    table[ModelBase.phrase.get(["name"])] = name;
    table[ModelBase.phrase.get(["category"])] = category;
    table[ModelBase.phrase.get(["duration_minutes"])] = durationMinutes.toString();
    table[ModelBase.phrase.get(["price"])] = price.toString();
    return table;
  }

  String get name => _data["name"];
  String get category => _data["category"];
  String get description => _data["description"];
  double get durationMinutes => _data["duration_minutes"];
  double get price => _data["price"];
  List<String> get roomIds => _data["room_ids"];
  List<String> get userIds => _data["user_ids"];
  List<ServiceAddon> get serviceAddons => _data["service_addons"];

  void set category(String value) { _data["category"] = value; }
  void set description(String value) { _data["description"] = value; }
  void set name(String value) { _data["name"] = value; }
  void set durationMinutes(double value) { _data["duration_minutes"] = value; }
  void set price(double value) { _data["price"] = value; }
  void set roomIds(List<String> value) { _data["room_ids"] = value; }
  void set userIds(List<String> value) { _data["user_ids"] = value; }
  void set serviceAddons(List<ServiceAddon> value) { _data["service_addons"] = new List.from(value); }
}

==> bokain_models-0.2.17.tar.gz: lib/src/editable_model/service.dart <==
part of model_base;

class Service extends EditableModel
{
  @override
  Service() : super()
  {
    serviceAddons = new List();
    roomIds = new List();
    userIds = new List();
  }

  @override
  Service.from(Service other) : super.from(other);

  @override
  Service.decode(Map<String, dynamic> d) : super.decode(d)
  {
    name = d["name"];
    category = d["category"];
    description = d["description"];
    durationMinutes = (d["duration_minutes"] is double) ? d["duration_minutes"] : d["duration_minutes"].toDouble();
    price = (d["price"] is double) ? d["price"] : d["price"].toDouble();
    roomIds = (d.containsKey("room_ids")) ? d["room_ids"] : new List();
    userIds = (d.containsKey(["user_ids"])) ? d["user_ids"] : new List();
    serviceAddons = new List();
    if (d.containsKey("service_addons"))
    {
      List<Map<String, dynamic>> addonsTable = d["service_addons"];
      for (Map<String, dynamic> row in addonsTable)
      {
        serviceAddons.add(new ServiceAddon(row["name"], row["price"], row["duration"]));
      }
    }
  }

  @override
  Map<String, dynamic> get encoded
  {
    Map<String, dynamic> d = super.encoded;
    d["service_addons"] = new List<Map<String, dynamic>>();
    for (ServiceAddon addon in serviceAddons)
    {
      d["service_addons"].add(addon.data);
    }

    return d;
  }

  @override
  Map<String, String> get toTable
  {
    Map<String, String> table = new Map();
    table[ModelBase.phrase.get(["name"])] = name;
    table[ModelBase.phrase.get(["category"])] = category;
    table[ModelBase.phrase.get(["duration_minutes"])] = durationMinutes.toString();
    table[ModelBase.phrase.get(["price"])] = price.toString();
    return table;
  }

  String get name => _data["name"];
  String get category => _data["category"];
  String get description => _data["description"];
  num get durationMinutes => _data["duration_minutes"];
  num get price => _data["price"];
  List<String> get roomIds => _data["room_ids"];
  List<String> get userIds => _data["user_ids"];
  List<ServiceAddon> get serviceAddons => _data["service_addons"];

  void set category(String value) { _data["category"] = value; }
  void set description(String value) { _data["description"] = value; }
  void set name(String value) { _data["name"] = value; }
  void set durationMinutes(num value) { _data["duration_minutes"] = value.toInt(); }
  void set price(num value) { _data["price"] = value.toDouble(); }
  void set roomIds(List<String> value) { _data["room_ids"] = value; }
  void set userIds(List<String> value) { _data["user_ids"] = value; }
  void set serviceAddons(List<ServiceAddon> value) { _data["service_addons"] = new List.from(value); }
}
